@@ -6,16 +6,18 @@ SpatialPixelsMeteorology<-function(points, data, dates, tolerance = sqrt(.Machin
   cc = spx@coords
   if(!inherits(data, "list")) stop("'data' has to be a list of data frames")
   if(length(data)!=ndates) stop("Number of data frames must be equal to the number of dates")
-  for(i in 1:ndates) {
-    if(!inherits(data[[i]], "data.frame")) stop("'data' has to be a list of data frames")
-    if(nrow(data[[i]])!=nrow(cc)) stop("Number of rows in all data frames have to be equal to the number of pixels")
-  }
-  nvar = ncol(data[[1]])
-  varnames = names(data[[1]])
-  if(ndates>1) {
-    for(i in 2:ndates) {
-      if(ncol(data[[i]])!=nvar) stop("Number of variables have to be the same for all data frames")
-      if(sum(names(data[[i]])==varnames)<nvar) stop("Variables need to be named equally in all data frames")
+  if(ndates>0) {
+    for(i in 1:ndates) {
+      if(!inherits(data[[i]], "data.frame")) stop("'data' has to be a list of data frames")
+      if(nrow(data[[i]])!=nrow(cc)) stop("Number of rows in all data frames have to be equal to the number of pixels")
+    }
+    nvar = ncol(data[[1]])
+    varnames = names(data[[1]])
+    if(ndates>1) {
+      for(i in 2:ndates) {
+        if(ncol(data[[i]])!=nvar) stop("Number of variables have to be the same for all data frames")
+        if(sum(names(data[[i]])==varnames)<nvar) stop("Variables need to be named equally in all data frames")
+      }
     }
   }
   spm = new("SpatialPixelsMeteorology",
@@ -96,3 +98,43 @@ print.SpatialPixelsMeteorology = function(x, ...) {
 setMethod("print", "SpatialPixelsMeteorology", function(x, ..., digits = getOption("digits")) print.SpatialPixelsMeteorology(x, ..., digits))
 setMethod("show", "SpatialPixelsMeteorology", function(object) print.SpatialPixelsMeteorology(object))
 
+
+as.SpPxMet.STFDF = function(from) {
+  datavec = from@data
+  data = datavec[[1]]
+  if(length(datavec)>1) {
+    for(i in 2:length(datavec)) {
+      data = rbind(data, datavec[[i]]) 
+    }
+  }
+  time = as.POSIXct(as.Date(from@dates))
+  sp = as(from, "SpatialPixels")
+  spacetime::STFDF(sp, time, data)
+}
+setAs("SpatialPixelsMeteorology", "STFDF", as.SpPxMet.STFDF)
+
+as.SpPxMet.SpPtsMet = function(from) {
+  points = as(from, "SpatialPoints")
+  dates = from@dates
+  indices = from@grid.index
+  npoints = length(indices)
+  ndates = length(dates)
+  data = vector("list",npoints)
+  rownames(points@coords) = 1:npoints
+  names(data) = 1:npoints
+  varnames = names(from@data[[1]])
+  for(i in 1:npoints) {
+    df = data.frame(matrix(NA, nrow = ndates, ncol=length(varnames)))
+    colnames(df)= varnames
+    rownames(df)=as.character(dates)
+    for(j in 1:ndates) df[j,] = from@data[[j]][i,]
+    data[[i]] = df
+  }
+  SpatialPointsMeteorology(points, data = data, dates = dates)
+}
+setAs("SpatialPixelsMeteorology", "SpatialPointsMeteorology", as.SpPxMet.SpPtsMet)
+
+as.SpPxMet.stars = function(from) {
+  stars::st_as_stars(as.SpPxMet.STFDF(from))
+}
+setAs("SpatialPixelsMeteorology", "stars", as.SpPxMet.stars)
